Description Usage Arguments Value
Optimally select m points from n > m samples generated from a target distribution of d dimensions.
1 |
smp |
n-by-d matrix of n d-dimensional sample points. |
scr |
n-by-d matrix of gradients of log target at |
stnd |
optional logical, either TRUE (default) or FALSE, indicating
whether or not to standardise the colums of |
pre |
optional string, either "id" (default), "med", "sclmed", or "smpcov", specifying the preconditioner to be used. Alternatively, a numeric string can be passed as the single length-scale parameter of an isotropic kernel. |
m-vector containing the row indices in smp (and scr)
of the selected points.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.